# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .policy_trigger import PolicyTrigger
import typing_extensions
import uuid
from ...core.serialization import FieldMetadata
from .response_chunk import ResponseChunk
from .inserted_audit_log import InsertedAuditLog
from .referenced_source import ReferencedSource
from .web_search_result import WebSearchResult
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class MessageReply(UniversalBaseModel):
    policy_triggers: typing.List[PolicyTrigger]
    conversation_id: typing_extensions.Annotated[uuid.UUID, FieldMetadata(alias="conversationId")]
    response: ResponseChunk
    warnings: typing.List[str]
    inserted_audit_log: InsertedAuditLog
    referenced_sources: typing_extensions.Annotated[
        typing.List[ReferencedSource], FieldMetadata(alias="referencedSources")
    ]
    sources_in_data_context: typing_extensions.Annotated[
        typing.List[ReferencedSource], FieldMetadata(alias="sourcesInDataContext")
    ]
    web_search_results: typing_extensions.Annotated[
        typing.List[WebSearchResult], FieldMetadata(alias="webSearchResults")
    ]
    message_id: typing_extensions.Annotated[uuid.UUID, FieldMetadata(alias="messageId")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import uuid
from ...core.serialization import FieldMetadata
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class SearchResultChunk(UniversalBaseModel):
    chunk_id: typing_extensions.Annotated[uuid.UUID, FieldMetadata(alias="chunkId")]
    chunk_index: typing_extensions.Annotated[int, FieldMetadata(alias="chunkIndex")]
    text: str
    score: float = pydantic.Field()
    """
    The similarity score between 0 and 1 for the search result. A higher number means the chunk is more relevant to the search query.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from .types.user_metadata_patch import UserMetadataPatch
from ..core.request_options import RequestOptions
from ..core.http_response import HttpResponse
from ..core.serialization import convert_and_respect_annotation_metadata
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper
from ..core.http_response import AsyncHttpResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawUsersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def metadata(
        self, *, request: typing.Sequence[UserMetadataPatch], request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[None]:
        """
        Bulk patch metadata for users

        Parameters
        ----------
        request : typing.Sequence[UserMetadataPatch]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            "v0/users/metadata",
            method="PATCH",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=typing.Sequence[UserMetadataPatch], direction="write"
            ),
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncRawUsersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def metadata(
        self, *, request: typing.Sequence[UserMetadataPatch], request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[None]:
        """
        Bulk patch metadata for users

        Parameters
        ----------
        request : typing.Sequence[UserMetadataPatch]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "v0/users/metadata",
            method="PATCH",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=typing.Sequence[UserMetadataPatch], direction="write"
            ),
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ...core.serialization import FieldMetadata
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class UserMetadataPatch(UniversalBaseModel):
    user_email: typing_extensions.Annotated[str, FieldMetadata(alias="userEmail")]
    metadata: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    Key-value object of metadata for user. Keys will be merged with any existing values but can also be set to `null` to effectively remove
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from ...core.serialization import FieldMetadata
from .collection_filtered_data import CollectionFilteredData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class DataFilter(UniversalBaseModel):
    semantic_search_terms: typing_extensions.Annotated[typing.List[str], FieldMetadata(alias="semanticSearchTerms")]
    web_search_term: typing_extensions.Annotated[typing.List[str], FieldMetadata(alias="webSearchTerm")]
    filtered_data_sources_per_collection: typing_extensions.Annotated[
        typing.List[CollectionFilteredData], FieldMetadata(alias="filteredDataSourcesPerCollection")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
